#ifdef EPOC
/*
**	This modules handles any routines specific to the PSION series
**	of SIBO computers.    The idea is to avoid using the C runtime
**	library as it increases the program size and also more
**	importantly it always opens the console screen.
*/

#include <plib.h>
#include "lib.h"
#include "cpoclib.h"

#if 0
/*
 *      For EPOC based systems the PLIB based start-up module
 *      does not break up the command line into ARGC, ARGV format,
 *      so we need to do it ourselves.  This is avery embryonic
 *      implementation that assumes whitespace seperators, and
 *      no other special characters.
 */
GLDEF_C VOID
BuildCommandLine (int * argcptr, char *** argvptr)
{
    TEXT * ptr;
    TEXT * ptrend;
    char **argv;

    ptr = *((TEXT **)0x24);
    *argcptr = 1;
    argv = *argvptr = p_alloc (2 * sizeof (char *));

    argv[0] = ptr;
    argv[1] = NULL;

    for (ptr += p_slen(ptr) + 1, ptrend = ptr + *ptr++ ; ptr < ptrend ; ptr++) {
        if (p_isspace((unsigned char)*ptr)) {
            continue;
        }
        argv = p_realloc (*argvptr, ((*argcptr) + 2) * sizeof (char *));
            if (argv == NULL) {
                return;
            } else {
                *argvptr = argv;
            }

            argv[*argcptr] = ptr;
            *argcptr += 1;
            argv[*argcptr] = NULL;
            while (ptr < ptrend && !p_isspace((unsigned char)*ptr)) {
                ptr++;
            }
            *ptr = '\0';
    }
    return;

}
#endif

/*
 *  On EPOC based systems there is no stderr file opened by default
 *  when using PLIB.  We will therefore try and open such a channel
 *  on the current default drive.
 *
 *  We will try and append to the file if it already exists.  This
 *  allows for batch compiles.  It is up to the CPOC front-end to
 *  delete the error file as required.
 */

int STDOUT;
void
openerror (void)
{
    TEXT errname[P_FNAMESIZE];
    VOID *pfcb;

    if (p_getenv("CPOC",errname) < 0)
        p_scpy (errname,"CPOC.LOG");

    if (p_open(&_filetable[1], errname, P_FREPLACE | P_FUPDATE | P_FSTREAM_TEXT) < 0) {
        /* we cannot output a failure message with no channel ! */
        p_panic(157);
    }
   STDOUT = 1;
}
#endif /* EPOC */
